/*
 * Copyright (C) 1998   Warren Jasper
 * All rights reserved.
 *
 */

/*
 * das08.h
 */

/* define which type of board we are using */

#define CIO_DAS08_AOL
/* #define CIO_DAS08_AOH */
/* #define CIO_DAS08_AOM */

#include <linux/ioctl.h>
#define IOCTL_MAGIC 'w'

/*  ioctl() values */

#define ADC_SET_GAINS       _IO(IOCTL_MAGIC,  1)
#define ADC_GET_GAINS       _IOR(IOCTL_MAGIC, 2, 4)
#define ADC_COUNTER0        _IO(IOCTL_MAGIC,  3)
#define ADC_COUNTER1        _IO(IOCTL_MAGIC,  4)
#define ADC_COUNTER2        _IO(IOCTL_MAGIC,  5)
#define ADC_GET_STATUS      _IO(IOCTL_MAGIC,  6)
#define ADC_GET_DIO         _IOR(IOCTL_MAGIC, 7, 4)
#define ADC_SET_DIO         _IO(IOCTL_MAGIC,  8)
#define DIO_SET_MODE        _IO(IOCTL_MAGIC,  9)
#define DIO_SET_DIRECTION   _IO(IOCTL_MAGIC, 10)
#define INTERRUPT_ENABLE    _IO(IOCTL_MAGIC, 11)
#define INTERRUPT_DISABLE   _IO(IOCTL_MAGIC, 12)

#define IOCTL_MAXNR 12         /* maxinum ordinal number */

/* open mode values */
#define ADC_SOFT_TRIGGER         (0x0)
#define ADC_EXTERNAL_TRIGGER     (0x2)

/* Digital I/O Modes */
#define MODE_IO            0
#define MODE_STROBE_IO     1
#define MODE_BIDIRECTIONAL 2

/* Digital I/O Direction Settings */
#define PORT_INPUT         1
#define PORT_OUTPUT        0
#define HIGH_PORT_INPUT    2
#define HIGH_PORT_OUTPUT   3
#define LOW_PORT_INPUT     4
#define LOW_PORT_OUTPUT    5


/* ioctl(COUNTER0) mode values */

#define CTR0_MODE0 (0x0 << 17)
#define CTR0_MODE1 (0x1 << 17)
#define CTR0_MODE2 (0x2 << 17)
#define CTR0_MODE3 (0x3 << 17)
#define CTR0_MODE4 (0x4 << 17)
#define CTR0_MODE5 (0x5 << 17)
#define CTR0_NOLOAD (0xff000000)

/*  General definitions */

#define MAX_FREQ 330000
#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long

/* Programmable Range and Gain Settings */

#ifdef CIO_DAS08_AOL
  #define BP_10_00V  0x08           /* +/- 10V      */
  #define BP_5_00V   0x00           /* +/-  5V      */
  #define BP_2_50V   0x02           /* +/-  2.5V    */
  #define BP_1_25V   0x04           /* +/-  1.25V   */
  #define BP_0_625V  0x06           /* +/-  0.625V  */
  #define UP_10_00V  0x01           /* 0 - 10V      */
  #define UP_5_00V   0x03           /* 0 - 5V       */
  #define UP_2_50V   0x05           /* 0 - 2.5V     */
  #define UP_1_25V   0x07           /* 0 - 1.25V    */
#endif

#ifdef CIO_DAS08_AOH
  #define BP_10_00V  0x08           /* +/- 10V      */
  #define BP_5_00V   0x00           /* +/-  5V      */
  #define BP_1_00V   0x0a           /* +/-  1V      */
  #define BP_0_50V   0x02           /* +/-  0.5V    */
  #define BP_0_10V   0x0c           /* +/-  0.1V    */
  #define BP_0_05V   0x04           /* +/-  0.05V   */
  #define BP_0_01V   0x0e           /* +/-  0.01V   */
  #define BP_0_005V  0x06           /* +/-  0.005V  */
  #define UP_10_00V  0x01           /* 0 - 10V      */
  #define UP_1_00V   0x03           /* 0 -  1V      */
  #define UP_0_10V   0x05           /* 0 -  0.1V    */
  #define UP_0_01V   0x07           /* 0 -  0.01    */
#endif

#ifdef CIO_DAS08_AOM
  #define BP_10_00V  0x08           /* +/- 10V      */
  #define BP_5_00V   0x00           /* +/-  5V      */
  #define BP_0_50V   0x0a           /* +/-  0.5V    */
  #define BP_0_05V   0x0c           /* +/-  0.05V   */
  #define BP_0_01V   0x0e           /* +/-  0.01V   */
  #define UP_10_00V  0x09           /* 0 - 10V      */
  #define UP_1_00V   0x0b           /* 0 -  1V      */
  #define UP_0_10V   0x0d           /* 0 -  0.1V    */
  #define UP_0_02V   0x0f           /* 0 -  0.02    */
#endif

/* digital output */
#define DIO_0 0x1
#define DIO_1 0x2
#define DIO_2 0x4
#define DIO_3 0x8







